@@ -7,15 +7,18 @@
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
 
 from dataclasses import dataclass
+from typing import Any
 
 
 @dataclass
 class DefocusAnalyzeResult:
-    stream_url: str
-    snapshot_done_at: float
-    analyzed_at: float
+    rtsp_url: str
     snapshot_file_id: str
+    snapshot_done_at: float
     reference_image_file_ids: list[str]
-    comparison_stopped_on_index: int
-    least_freq_diff: float | None
-    certainty: float
+    detector_requests: list[dict[Any, Any]]
+    detector_results: list[dict[Any, Any]]
+    comparison_settings: dict[str, Any]
+    comparison_results: list[float]
+    result: float
+    analyzed_at: float
